@@ -12,7 +12,7 @@ __copyright__ = 'Copyright 2014, Lucas Ou-Yang'
 from .article import Article, ArticleException
 from .source import Source
 
-from .api import build, build_article, popular_urls, hot
+from .api import build, build_article, popular_urls, hot, languages
 from .api import NewsPool, Configuration as Config
 
 news_pool = NewsPool()
